==> eiffelstudio-18.11.10.2592.tar: F_code/C4/fo150.c <==
/*
 * Code for class FORMAT_DOUBLE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "fo150.h"
#include <math.h>
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {FORMAT_DOUBLE}.make */
void F172_3350 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	F80_2405(Current, arg1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_) = (EIF_INTEGER_32) arg2;
	*(EIF_CHARACTER_8 *)(Current+ _CHROFF_1_2_) = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '.';
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_7_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {FORMAT_DOUBLE}.formatted */
EIF_REFERENCE F172_3368 (EIF_REFERENCE Current, EIF_REAL_64 arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REAL_64 loc2 = (EIF_REAL_64) 0;
	EIF_REAL_64 loc3 = (EIF_REAL_64) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REAL_64 loc6 = (EIF_REAL_64) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REAL_64 tr8_1;
	EIF_REAL_64 tr8_2;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,loc4);
	RTLR(2,tr1);
	RTLR(3,loc5);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	loc6 = (EIF_REAL_64) arg1;
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) 0L));
	if ((EIF_BOOLEAN) (arg1 < tr8_1)) {
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
		loc6 = (EIF_REAL_64) (EIF_REAL_64) -loc6;
	}
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) 5L));
	tr8_2 = (EIF_REAL_64) (((EIF_INTEGER_32) ((EIF_INTEGER_32) -*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_) - ((EIF_INTEGER_32) 1L))));
	loc6 += (EIF_REAL_64) (tr8_1 * (EIF_REAL_64) pow ((EIF_REAL_64) (((EIF_INTEGER_32) 10L)), (EIF_REAL_64) (tr8_2)));
	loc2 = (EIF_REAL_64) floor((double) loc6);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_);
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L))));
	loc3 = (EIF_REAL_64) floor((double) (EIF_REAL_64) ((EIF_REAL_64) (loc6 - loc2) * (EIF_REAL_64) pow ((EIF_REAL_64) (((EIF_INTEGER_32) 10L)), (EIF_REAL_64) (tr8_1))));
	if ((EIF_BOOLEAN) !F80_2422(Current)) {
		tr1 = c_outr64(loc2);
		loc4 = F80_2462(Current, tr1);
		if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_5_)) {
			tr1 = F172_3369(Current, loc3);
			loc5 = F172_3370(Current, tr1);
		} else {
			loc5 = F172_3369(Current, loc3);
		}
	} else {
		loc4 = c_outr64(loc2);
		loc5 = F172_3369(Current, loc3);
	}
	tr1 = RTLNS(eif_new_type(1014, 0x01).id, 1014, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1013_8553(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_0_));
	Result = (EIF_REFERENCE) tr1;
	tb1 = '\01';
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) 0L));
	if (!(EIF_BOOLEAN)(loc2 != tr8_1)) {
		tb1 = (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_6_);
	}
	if (tb1) {
		F1015_8664(RTCW(Result), loc4);
	}
	tb1 = F1013_8587(RTCW(Result), (EIF_CHARACTER_8) 'e');
	if ((EIF_BOOLEAN) !tb1) {
		F1015_8679(RTCW(Result), *(EIF_CHARACTER_8 *)(Current+ _CHROFF_1_2_));
		if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_) > ((EIF_INTEGER_32) 0L))) {
			F1015_8664(RTCW(Result), loc5);
		}
		if ((EIF_BOOLEAN) !F80_2421(Current)) {
			Result = F80_2463(Current, Result, loc1);
		}
	}
	tb1 = '\0';
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_1_) != ((EIF_INTEGER_32) 0L))) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
		tb1 = (EIF_BOOLEAN) (ti4_1 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_0_));
	}
	if (tb1) {
		RTLE;
		return (EIF_REFERENCE) F80_2466(Current, Result);
	}
	RTLE;
	return Result;
}

/* {FORMAT_DOUBLE}.pad_fraction */
EIF_REFERENCE F172_3369 (EIF_REFERENCE Current, EIF_REAL_64 arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_CHARACTER_8 tc1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	Result = c_outr64(arg1);
	F1015_8687(RTCW(Result), ((EIF_INTEGER_32) 1L));
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
	if ((EIF_BOOLEAN) (ti4_1 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_))) {
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_);
		Result = F1015_8710(RTCW(Result), ((EIF_INTEGER_32) 1L), ti4_1);
	} else {
		for (;;) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
			if ((EIF_BOOLEAN)(ti4_1 == *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_))) break;
			F1015_8653(RTCW(Result), (EIF_CHARACTER_8) '0');
		}
	}
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_7_)) {
		loc1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
		for (;;) {
			tb1 = '\01';
			if (!(EIF_BOOLEAN) (loc1 <= ((EIF_INTEGER_32) 1L))) {
				tc1 = F1015_8629(RTCW(Result), loc1);
				tb1 = (EIF_BOOLEAN)(tc1 != (EIF_CHARACTER_8) '0');
			}
			if (tb1) break;
			F1015_8684(RTCW(Result), loc1);
			loc1--;
		}
	}
	RTLE;
	return Result;
}

/* {FORMAT_DOUBLE}.separate_fraction */
EIF_REFERENCE F172_3370 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_CHARACTER_8 tc1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLR(2,Result);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	tr1 = RTLNS(eif_new_type(1014, 0x01).id, 1014, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1013_8553(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_0_));
	Result = (EIF_REFERENCE) tr1;
	for (;;) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (loc1 > (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 3L)))) break;
		loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
		for (;;) {
			if ((EIF_BOOLEAN)(loc2 == ((EIF_INTEGER_32) 3L))) break;
			tc1 = F1015_8629(RTCW(arg1), loc1);
			F1015_8679(RTCW(Result), tc1);
			loc1++;
			loc2++;
		}
		F1015_8679(RTCW(Result), *(EIF_CHARACTER_8 *)(Current+ _CHROFF_1_1_));
	}
	for (;;) {
		ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (loc1 > ti4_2)) break;
		tc1 = F1015_8629(RTCW(arg1), loc1);
		F1015_8679(RTCW(Result), tc1);
		loc1++;
	}
	RTLE;
	return Result;
}

void EIF_Minit150 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/fo150.c <==
/*
 * Code for class FORMAT_DOUBLE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "fo150.h"
#include <math.h>
#include "eif_helpers.h"
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {FORMAT_DOUBLE}.make */
void F172_2742 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	F73_1912(Current, arg1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_) = (EIF_INTEGER_32) arg2;
	*(EIF_CHARACTER_8 *)(Current+ _CHROFF_1_2_) = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '.';
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_7_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {FORMAT_DOUBLE}.formatted */
EIF_REFERENCE F172_2760 (EIF_REFERENCE Current, EIF_REAL_64 arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REAL_64 loc2 = (EIF_REAL_64) 0;
	EIF_REAL_64 loc3 = (EIF_REAL_64) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REAL_64 loc6 = (EIF_REAL_64) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REAL_64 tr8_1;
	EIF_REAL_64 tr8_2;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,loc4);
	RTLR(2,tr1);
	RTLR(3,loc5);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	loc6 = (EIF_REAL_64) arg1;
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) 0L));
	if ((EIF_BOOLEAN) eif_is_less_real_64 (arg1, tr8_1)) {
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
		loc6 = (EIF_REAL_64) (EIF_REAL_64) -loc6;
	}
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) 5L));
	tr8_2 = (EIF_REAL_64) (((EIF_INTEGER_32) ((EIF_INTEGER_32) -*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_) - ((EIF_INTEGER_32) 1L))));
	loc6 += (EIF_REAL_64) (tr8_1 * (EIF_REAL_64) pow ((EIF_REAL_64) (((EIF_INTEGER_32) 10L)), (EIF_REAL_64) (tr8_2)));
	loc2 = (EIF_REAL_64) floor((double) loc6);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_);
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L))));
	loc3 = (EIF_REAL_64) floor((double) (EIF_REAL_64) ((EIF_REAL_64) (loc6 - loc2) * (EIF_REAL_64) pow ((EIF_REAL_64) (((EIF_INTEGER_32) 10L)), (EIF_REAL_64) (tr8_1))));
	if ((EIF_BOOLEAN) !F73_1929(Current)) {
		tr1 = c_outr64(loc2);
		loc4 = F73_1969(Current, tr1);
		if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_5_)) {
			tr1 = F172_2761(Current, loc3);
			loc5 = F172_2762(Current, tr1);
		} else {
			loc5 = F172_2761(Current, loc3);
		}
	} else {
		loc4 = c_outr64(loc2);
		loc5 = F172_2761(Current, loc3);
	}
	Result = RTLNS(eif_new_type(924, 0x00).id, 924, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F923_7444(RTCW(Result), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_0_));
	tb1 = '\01';
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) 0L));
	if (!(EIF_BOOLEAN) !eif_is_equal_real_64 (loc2, tr8_1)) {
		tb1 = (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_6_);
	}
	if (tb1) {
		F925_7555(RTCW(Result), loc4);
	}
	tb1 = F923_7478(RTCW(Result), (EIF_CHARACTER_8) 'e');
	if ((EIF_BOOLEAN) !tb1) {
		F925_7570(RTCW(Result), *(EIF_CHARACTER_8 *)(Current+ _CHROFF_1_2_));
		if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_) > ((EIF_INTEGER_32) 0L))) {
			F925_7555(RTCW(Result), loc5);
		}
		if ((EIF_BOOLEAN) !F73_1928(Current)) {
			tr1 = F73_1970(Current, Result, loc1);
			Result = (EIF_REFERENCE) tr1;
		}
	}
	tb1 = '\0';
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_1_) != ((EIF_INTEGER_32) 0L))) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
		tb1 = (EIF_BOOLEAN) (ti4_1 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_0_));
	}
	if (tb1) {
		RTLE;
		return (EIF_REFERENCE) F73_1973(Current, Result);
	}
	RTLE;
	return Result;
}

/* {FORMAT_DOUBLE}.pad_fraction */
EIF_REFERENCE F172_2761 (EIF_REFERENCE Current, EIF_REAL_64 arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_CHARACTER_8 tc1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	Result = c_outr64(arg1);
	F925_7578(RTCW(Result), ((EIF_INTEGER_32) 1L));
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
	if ((EIF_BOOLEAN) (ti4_1 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_))) {
		tr1 = F925_7601(RTCW(Result), ((EIF_INTEGER_32) 1L), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_));
		Result = (EIF_REFERENCE) tr1;
	} else {
		for (;;) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
			if ((EIF_BOOLEAN)(ti4_1 == *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_))) break;
			F925_7544(RTCW(Result), (EIF_CHARACTER_8) '0');
		}
	}
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_7_)) {
		loc1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
		for (;;) {
			tb1 = '\01';
			if (!(EIF_BOOLEAN) (loc1 <= ((EIF_INTEGER_32) 1L))) {
				tc1 = F925_7520(RTCW(Result), loc1);
				tb1 = (EIF_BOOLEAN)(tc1 != (EIF_CHARACTER_8) '0');
			}
			if (tb1) break;
			F925_7575(RTCW(Result), loc1);
			loc1--;
		}
	}
	RTLE;
	return Result;
}

/* {FORMAT_DOUBLE}.separate_fraction */
EIF_REFERENCE F172_2762 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_CHARACTER_8 tc1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	Result = RTLNS(eif_new_type(924, 0x00).id, 924, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F923_7444(RTCW(Result), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_0_));
	for (;;) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (loc1 > (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 3L)))) break;
		loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
		for (;;) {
			if ((EIF_BOOLEAN)(loc2 == ((EIF_INTEGER_32) 3L))) break;
			tc1 = F925_7520(RTCW(arg1), loc1);
			F925_7570(RTCW(Result), tc1);
			loc1++;
			loc2++;
		}
		F925_7570(RTCW(Result), *(EIF_CHARACTER_8 *)(Current+ _CHROFF_1_1_));
	}
	for (;;) {
		ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (loc1 > ti4_2)) break;
		tc1 = F925_7520(RTCW(arg1), loc1);
		F925_7570(RTCW(Result), tc1);
		loc1++;
	}
	RTLE;
	return Result;
}

void EIF_Minit150 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
